<?php
/**
 * Krystal Shop Theme Customizer
 *
 * @package krystal-shop
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

if ( ! function_exists( 'krystal_shop_customize_register' ) ) :
function krystal_shop_customize_register( $wp_customize ) {


    // Add custom controls.

    require_once( get_stylesheet_directory(). '/inc/customizer/custom-controls/info/class-info-control.php' );
    require_once( get_stylesheet_directory(). '/inc/customizer/custom-controls/info/class-title-info-control.php' );
    require_once( get_stylesheet_directory(). '/inc/customizer/custom-controls/toggle-button/class-login-designer-toggle-control.php' );
    require_once( get_stylesheet_directory(). '/inc/customizer/custom-controls/radio-images/class-radio-image-control.php' );

    // Register the custom control type.
    $wp_customize->register_control_type( 'Krystal_Shop_Toggle_Control' ); 


    if(krystal_shop_is_woocommerce_activated()){

         //Shop Settings
        
        $wp_customize->add_section(
            'krystal_shop_settings',
            array (
                'priority'      => 25,
                'capability'    => 'edit_theme_options',
                'theme_supports'=> '',
                'title'         => esc_html__( 'Shop Settings', 'krystal-shop' )
            )
        );

        // Info label
        $wp_customize->add_setting( 
            'kr_label_shop_settings_section', 
            array(
                'sanitize_callback' => 'krystal_shop_sanitize_title',
            ) 
        );

        $wp_customize->add_control( 
            new Krystal_Shop_Title_Info_Control( $wp_customize, 'kr_label_shop_settings_section', 
            array(
                'label'       => esc_html__( 'Shop Settings', 'krystal-shop' ),
                'section'     => 'krystal_shop_settings',
                'type'        => 'krystal-shop-title',
                'settings'    => 'kr_label_shop_settings_section',
            ) 
        ));

        // cart menu
        $wp_customize->add_setting(
            'kr_menu_cart',
            array(
                'type' => 'theme_mod',
                'default'           => true,
                'sanitize_callback' => 'krystal_shop_sanitize_checkbox_selection'
            )
        );

        $wp_customize->add_control(
            new Krystal_Shop_Toggle_Control( $wp_customize, 'kr_menu_cart', 
            array(
                'settings'      => 'kr_menu_cart',
                'section'       => 'krystal_shop_settings',
                'type'          => 'krystal-shop-toggle',
                'label'         => esc_html__( 'Show Menu Cart:', 'krystal-shop' ),
                'description'   => esc_html__( 'This will add a cart icon in primary menu of website', 'krystal-shop' ),
            )
        ));

        // Info label
        $wp_customize->add_setting( 
            'kr_label_shop_name_settings_section', 
            array(
                'sanitize_callback' => 'krystal_shop_sanitize_title',
            ) 
        );

        $wp_customize->add_control( 
            new Krystal_Shop_Title_Info_Control( $wp_customize, 'kr_label_shop_name_settings_section', 
            array(
                'label'       => esc_html__( 'Shop Name', 'krystal-shop' ),
                'section'     => 'krystal_shop_settings',
                'type'        => 'krystal-shop-title',
                'settings'    => 'kr_label_shop_name_settings_section',
            ) 
        ));

        // Shop Name 
        $wp_customize->add_setting(
            'kr_shop_name',
            array(
                'type' => 'theme_mod',
                'default'           => esc_html__('SHOP','krystal-shop'),
                'sanitize_callback' => 'krystal_shop_sanitize_textarea',            
            )
        );

        $wp_customize->add_control(
            'kr_shop_name',
            array(
                'settings'      => 'kr_shop_name',
                'section'       => 'krystal_shop_settings',
                'type'          => 'textbox',
                'label'         => esc_html__( 'Shop Name', 'krystal-shop' ),
                'description'   => '',
            )
        );

        // Info label
        $wp_customize->add_setting( 
            'kr_label_shop_sidebar_settings_section', 
            array(
                'sanitize_callback' => 'krystal_shop_sanitize_title',
            ) 
        );

        $wp_customize->add_control( 
            new Krystal_Shop_Title_Info_Control( $wp_customize, 'kr_label_shop_sidebar_settings_section', 
            array(
                'label'       => esc_html__( 'Shop Sidebar', 'krystal-shop' ),
                'section'     => 'krystal_shop_settings',
                'type'        => 'krystal-shop-title',
                'settings'    => 'kr_label_shop_sidebar_settings_section',
            ) 
        ));

        // Shop Styles
        $wp_customize->add_setting(
            'kr_shop_styles',
            array(
                'type' => 'theme_mod',
                'default'           => 'default',
                'sanitize_callback' => 'krystal_shop_sanitize_shop_styles_selection'
            )
        );

        $wp_customize->add_control(
            'kr_shop_styles',
            array(
                'settings'      => 'kr_shop_styles',
                'section'       => 'krystal_shop_settings',
                'type'          => 'radio',
                'label'         => esc_html__( 'Select Sidebar Position:', 'krystal-shop' ),
                'description'   => '',
                'choices' => array(
                                'default' => esc_html__('Full Width', 'krystal-shop'),
                                'right' => esc_html__('Rignt Sidebar', 'krystal-shop'),
                                'left' => esc_html__('Left Sidebar', 'krystal-shop'),
                                ),
            )
        );

        // Info label
        $wp_customize->add_setting( 
            'kr_label_shop_button_settings_section', 
            array(
                'sanitize_callback' => 'krystal_shop_sanitize_title',
            ) 
        );

        $wp_customize->add_control( 
            new Krystal_Shop_Title_Info_Control( $wp_customize, 'kr_label_shop_button_settings_section', 
            array(
                'label'       => esc_html__( 'Shop Buttons', 'krystal-shop' ),
                'section'     => 'krystal_shop_settings',
                'type'        => 'krystal-shop-title',
                'settings'    => 'kr_label_shop_button_settings_section',
            ) 
        ));

        // Button Styles
        $wp_customize->add_setting(
            'kr_shop_button_styles',
            array(
                'type' => 'theme_mod',
                'default'           => 'solid',
                'sanitize_callback' => 'krystal_shop_sanitize_button_styles_selection'
            )
        );

        $wp_customize->add_control(
            'kr_shop_button_styles',
            array(
                'settings'      => 'kr_shop_button_styles',
                'section'       => 'krystal_shop_settings',
                'type'          => 'radio',
                'label'         => esc_html__( 'Select Button Color:', 'krystal-shop' ),
                'description'   => '',
                'choices' => array(
                                'transparent' => esc_html__('Transparent Color', 'krystal-shop'),
                                'solid' => esc_html__('Solid Color', 'krystal-shop'),
                                ),
            )
        );           
    }  
   
}
endif;

add_action( 'customize_register', 'krystal_shop_customize_register' );

/**
 * Sanitize textarea.
 *
 * @param string $input
 * @return string
 */
if ( ! function_exists( 'krystal_shop_sanitize_textarea' ) ) :
function krystal_shop_sanitize_textarea( $input ) {
    return sanitize_textarea_field( $input );
}
endif;


/**
 * Sanitize Shop sidebar radio option 
 *
 * @param string $input
 * @return string
 */
if ( ! function_exists( 'krystal_shop_sanitize_shop_styles_selection' ) ) :
function krystal_shop_sanitize_shop_styles_selection(  $input ){
    $valid = array(
        'default' => esc_html__('Full Width', 'krystal-shop'),
        'right' => esc_html__('Rignt Sidebar', 'krystal-shop'),
        'left' => esc_html__('Left Sidebar', 'krystal-shop'),      
     );

     if ( array_key_exists( $input, $valid ) ) {
        return $input;
     } else {
        return '';
     }
}
endif;

/**
 * Sanitize Shop buttons radio option 
 *
 * @param string $input
 * @return string
 */
if ( ! function_exists( 'krystal_shop_sanitize_button_styles_selection' ) ) :
function krystal_shop_sanitize_button_styles_selection(  $input ){
    $valid = array(
        'transparent' => esc_html__('Transparent Color', 'krystal-shop'),
        'solid' => esc_html__('Solid Color', 'krystal-shop'),      
     );

     if ( array_key_exists( $input, $valid ) ) {
        return $input;
     } else {
        return '';
     }
}
endif;

/**
 * Sanitize checkbox.
 *
 * @param bool $checked Whether the checkbox is checked.
 * @return bool Whether the checkbox is checked.
 */
if ( ! function_exists( 'krystal_shop_sanitize_checkbox_selection' ) ) :
function krystal_shop_sanitize_checkbox_selection( $checked ) {
    // Boolean check.
    return ( ( isset( $checked ) && true == $checked ) ? true : false );
}
endif;


/**
 * Title sanitization.
 */
if ( ! function_exists( 'krystal_shop_sanitize_title' ) ) :
function krystal_shop_sanitize_title( $str ) {
    return sanitize_title( $str );  
}
endif;
